@@ -12,7 +12,7 @@ int vw_printw(WINDOW *win, const char *fmt, va_list varglist)
 
 #  include <stdio.h>
 
-#  warning Using a (limited) custom implementation of vw_printw
+#  warning Using a limited implementation of vw_printw with a fixed maximum size
 
 int vw_printw(WINDOW *win, const char *fmt, va_list varglist)
 {
