@@ -14,7 +14,18 @@
 
 #include "irmp3-ncurses.h"
 
-vcid("$Id: poll-select.c,v 1.5 2005/03/26 21:03:48 ross Exp $");
+vcid("$Id: poll-select.c,v 1.8 2006/01/10 01:53:52 ross Exp $");
+
+
+void block_net(void)
+{
+    return;
+}
+
+void unblock_net(void)
+{
+    return;
+}
 
 
 int main_poll_loop(int sock)
@@ -27,10 +38,10 @@ int main_poll_loop(int sock)
 	FD_SET(sock, &fds);
 	if(-1 == select(max(STDIN_FILENO, sock) + 1, &fds,
 			NULL, NULL, NULL)) {
-	    if(errno == EINTR)
+	    if(sock_errno == SOCK_EINTR)
 		continue;
-	    sbar_printf(_("select() failed with error %s (%d)"),
-			strerror(errno), errno);
+	    sbar_printf("select(): %s (%d)",
+			sock_strerror(sock_errno), sock_errno);
 	    error_sleep();
 	    break;
 	}
