@@ -14,12 +14,23 @@
 
 #include "irmp3-ncurses.h"
 
-vcid("$Id: poll-wthread.c,v 1.4 2005/03/15 01:06:29 ross Exp $");
+vcid("$Id: poll-wthread.c,v 1.5 2005/12/30 13:18:48 ross Exp $");
 
 
 
 HANDLE hsock_thread;
 
+void block_net(void)
+{
+    return;
+}
+
+void unblock_net(void)
+{
+    return;
+}
+
+
 static DWORD WINAPI sock_thread(void *param)
 {
     int const sock = (int)param;
