@@ -12,9 +12,19 @@
 
 #include "irmp3-ncurses.h"
 
-vcid("$Id: stub-scroller.c,v 1.4 2005/03/21 10:36:24 ross Exp $");
+vcid("$Id: stub-scroller.c,v 1.5 2005/12/30 13:18:48 ross Exp $");
 
 
+void block_scroller(void)
+{
+    return;
+}
+
+void unblock_scroller(void)
+{
+    return;
+}
+
 void wscroller_hook(WINDOW **wnd, struct scroller *scroller, const char *msg,
 		    bool right, void *(*entryhook)(struct scroller *),
 		    void (*exithook)(struct scroller *, void *))
@@ -52,4 +62,5 @@ void scroller_end(struct scroller *scroller)
 
 void scroller_endall(void)
 {
+    return;
 }
